@@ -261,7 +261,7 @@ __DATA__
 %   if ($key eq 'value') {
     <input type="text" name="<%= $key %>" id="<%= $key %>" value="<%= $selected->{value} %>" class="form-control">
 %   } elsif ($key eq 'is_default') {
-    Is default:
+    Is default: &nbsp;
     <div class="form-check form-check-inline">
       <input class="form-check-input" type="radio" name="<%= $key %>" id="is_default_true" value="1" <%= $selected->{is_default} ? 'checked' : '' %>>
       <label class="form-check-label" for="is_default_true">True</label>
@@ -281,16 +281,17 @@ __DATA__
 %     }
     </select>
 %   }
-    <p></p>
 %   if ($j != $specs->{order}->@*) {
   </div>
 %     unless ($key eq 'group' || $key eq 'group_to' || $key eq 'bottom' || $key eq 'value') {
 </div>
+<p id="<%= $key . '_p' %>"></p>
 %     }
 %   }
 % }
   </div>
 </div>
+  <p></p>
   <input type="submit" value="Submit" class="btn btn-primary">
   <a href="<%= url_for('remove')->query(id => $id, model => $model, name => $name) %>" class="btn btn-danger" onclick="if(!confirm('Remove setting <%= $id %>?')) return false;">Remove</a>
   <a href="<%= url_for('index')->query(model => $model, name => $name) %>" class="btn btn-warning">Cancel</a>
@@ -323,36 +324,48 @@ $(document).ready(function() {
     if (selected === 'patch') {
       $('label[for="group_to"]').show();
       $("#group_to").show();
+      $("#group_to_p").show();
       $('label[for="param_to"]').show();
       $("#param_to").show();
+      $("#param_to_p").show();
       $("#bottom").val($("#bottom option:first").val());
       $('label[for="bottom"]').hide();
       $("#bottom").hide();
+      $("#bottom_p").hide();
       $("#top").val($("#top option:first").val());
       $('label[for="top"]').hide();
       $("#top").hide();
+      $("#top_p").hide();
       $("#value").val('');
       $('label[for="value"]').hide();
       $("#value").hide();
+      $("#value_p").hide();
       $("#unit").val($("#unit option:first").val());
       $('label[for="unit"]').hide();
       $("#unit").hide();
+      $("#unit_p").hide();
     }
     else {
       $("#group_to").val($("#group_to option:first").val());
       $('label[for="group_to"]').hide();
       $("#group_to").hide();
+      $("#group_to_p").hide();
       $("#param_to").val($("#param_to option:first").val());
       $('label[for="param_to"]').hide();
       $("#param_to").hide();
+      $("#param_to_p").hide();
       $('label[for="bottom"]').show();
       $("#bottom").show();
+      $("#bottom_p").show();
       $('label[for="top"]').show();
       $("#top").show();
+      $("#top_p").show();
       $('label[for="value"]').show();
       $("#value").show();
+      $("#value_p").show();
       $('label[for="unit"]').show();
       $("#unit").show();
+      $("#unit_p").show();
     }
   });
 });
