@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0018';
+our $VERSION = '0.0019';
 
 use Moo;
 use strictures 2;
@@ -204,13 +204,15 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0018
+version 0.0019
 
 =head1 SYNOPSIS
 
   use Synth::Config ();
 
-  my $synth = Synth::Config->new(model => 'Moog Matriarch');
+  my $model = 'Moog Matriarch';
+
+  my $synth = Synth::Config->new(model => $model);
 
   my $name = 'Foo!';
 
@@ -233,6 +235,8 @@ version 0.0018
 
   $synth->remove_settings(name => $name);
 
+  $synth->remove_model(model => $model);
+
 =head1 DESCRIPTION
 
 C<Synth::Config> provides a way to save and recall synthesizer control
